@@ -36,8 +36,8 @@ let register_sender scope service write =
   Eliom_registration.Action.register ~scope ~options:`NoReload ~service
     (fun () x -> Lwt_list.iter_s write x)
 
-let internal_wrap (bus : ('a, 'b) t)
-    : ('a, 'b) Ecb.wrapped_bus * Eliom_common.unwrapper
+let internal_wrap (bus : ('a, 'b) t) :
+    ('a, 'b) Ecb.wrapped_bus * Eliom_common.unwrapper
   =
   let channel =
     match bus.channel with
@@ -57,17 +57,17 @@ let internal_wrap (bus : ('a, 'b) t)
         register_sender bus.scope
           (srv
             :> ( _
-               , _ list
-               , _
-               , _
-               , _
-               , Eliom_service.non_ext
-               , _
-               , _
-               , _
-               , _
-               , _ )
-               Eliom_service.t)
+                 , _ list
+                 , _
+                 , _
+                 , _
+                 , Eliom_service.non_ext
+                 , _
+                 , _
+                 , _
+                 , _
+                 , _ )
+                 Eliom_service.t)
           bus.write;
         Eliom_state.set_volatile_data ~table true));
   ( (Eliom_comet.Channel.get_wrapped channel, bus.service)
@@ -76,17 +76,17 @@ let internal_wrap (bus : ('a, 'b) t)
 let bus_mark () = Eliom_common.make_wrapper internal_wrap
 
 let deriving_to_list : 'a Deriving_Json.t -> 'a list Deriving_Json.t =
-  fun (type typ) typ ->
-   let (typ_list : typ list Deriving_Json.t) =
-     let module M = Deriving_Json.Json_list (Deriving_Json.Defaults'' (struct
-       type a = typ
+ fun (type typ) typ ->
+  let (typ_list : typ list Deriving_Json.t) =
+    let module M = Deriving_Json.Json_list (Deriving_Json.Defaults'' (struct
+        type a = typ
 
-       let t = typ
-     end))
-     in
-     M.t
-   in
-   typ_list
+        let t = typ
+      end))
+    in
+    M.t
+  in
+  typ_list
 
 let create_filtered ?scope ?name ?size ~filter typ =
   (*The stream*)
@@ -112,7 +112,7 @@ let create_filtered ?scope ?name ?size ~filter typ =
   (*The service*)
   let post_params =
     (Eliom_parameter.ocaml "bus_write" typ_list
-      : ('a, 'aa, 'aaa) Eliom_parameter.params_type)
+     : ('a, 'aa, 'aaa) Eliom_parameter.params_type)
   in
   let distant_write =
     Eliom_service.create ?name
