@@ -26,6 +26,7 @@ exception
   Eliom_there_are_unregistered_services of
     (string list * string list list * na_key_serv list)
 
+exception Cannot_call_this_function_before_app_is_linked_to_a_site
 exception Eliom_error_while_loading_site of string
 exception Eliom_do_redirection of string
 exception Eliom_do_half_xhr_redirection of string
@@ -421,9 +422,11 @@ and tables =
   }
 
 and sitedata =
-  { site_dir : Url.path
-  ; site_dir_string : string
-  ; config_info : Ocsigen_extensions.config_info
+  { mutable site_dir : Url.path option
+        (* None when statically linked 
+                                           before module init*)
+  ; mutable site_dir_string : string option (* idem *)
+  ; mutable config_info : Ocsigen_extensions.config_info option (* idem *)
   ; default_links_xhr : bool tenable_value
   ; (* Timeouts:
        - default for site (browser sessions)
@@ -492,6 +495,14 @@ and dlist_ip_table =
   (page_table ref * page_table_key, na_key_serv) leftright Ocsigen_cache.Dlist.t
     Net_addr_Hashtbl.t
 
+let check_initialised field =
+  match field with
+  | None -> raise Cannot_call_this_function_before_app_is_linked_to_a_site
+  | Some a -> a
+
+let get_site_dir sitedata = check_initialised sitedata.site_dir
+let get_site_dir_string sitedata = check_initialised sitedata.site_dir_string
+let get_config_info sitedata = check_initialised sitedata.config_info
 let create_dlist_ip_table = Net_addr_Hashtbl.create
 
 let find_dlist_ip_table :
@@ -525,7 +536,7 @@ let make_full_state_name2 site_dir_str secure ~(scope : [< user_scope]) :
   {user_scope = (scope :> user_scope); secure; site_dir_str}
 
 let make_full_state_name ~sp ~secure ~(scope : [< user_scope]) =
-  make_full_state_name2 sp.sp_sitedata.site_dir_string secure ~scope
+  make_full_state_name2 (get_site_dir_string sp.sp_sitedata) secure ~scope
 
 let get_cookie_info sp = function
   | `Session -> sp.sp_cookie_info
@@ -685,17 +696,11 @@ let verify_all_registered sitedata =
   match sitedata.unregistered_services, sitedata.unregistered_na_services with
   | [], [] -> ()
   | l1, l2 ->
-      raise (Eliom_there_are_unregistered_services (sitedata.site_dir, l1, l2))
-
-let during_eliom_module_loading, begin_load_eliom_module, end_load_eliom_module =
-  let during_eliom_module_loading_ = ref false in
-  ( (fun () -> !during_eliom_module_loading_)
-  , (fun () -> during_eliom_module_loading_ := true)
-  , fun () -> during_eliom_module_loading_ := false )
+      raise
+        (Eliom_there_are_unregistered_services (get_site_dir sitedata, l1, l2))
 
 let global_register_allowed () =
   if Ocsigen_extensions.during_initialisation ()
-     && during_eliom_module_loading ()
   then Some get_current_sitedata
   else None
 
@@ -703,7 +708,7 @@ let get_site_data () =
   match get_sp_option () with
   | Some sp -> sp.sp_sitedata
   | None ->
-      if during_eliom_module_loading ()
+      if Ocsigen_extensions.during_initialisation ()
       then get_current_sitedata ()
       else failwith "get_site_data"
 
@@ -1414,9 +1419,6 @@ let patch_request_info ({Ocsigen_extensions.request_info; _} as r) =
            Ocsigen_request.update ~get_params_flat request_info) }
   | None -> r
 
-let get_site_dir sitedata = sitedata.site_dir
-let get_site_dir_string sitedata = sitedata.site_dir_string
-
 (* Returns if we want secure cookie *)
 let get_secure ~secure_o ~sitedata () =
   match secure_o with None -> sitedata.secure_cookies | Some s -> s
@@ -1448,3 +1450,17 @@ module To_and_of_shared = struct
 end
 
 let client_html_file () = failwith "client_html_file is only defined on client"
+let default_app_name = "__eliom_default_app__"
+let current_app_name = ref default_app_name
+let get_app_name () = !current_app_name
+
+let defer get f =
+  let r = ref None in
+  (match get () with
+  | Some v -> r := Some (f v)
+  | None ->
+      Ocsigen_loader.add_module_init_function (get_app_name ()) (fun () ->
+        match get () with
+        | Some v -> r := Some (f v)
+        | None -> raise (Eliom_site_information_not_available "defer")));
+  r
