@@ -35,15 +35,76 @@ v}
 
 *)
 
+val set_session_gc_frequency : int option -> unit
+(** Set frequency 
+    for garnage collection of both in memory data and service sessions.
+    [None] means never. *)
+
+val set_service_session_gc_frequency : int option -> unit
+(** Set frequency for garbage collection of service sessions.
+    [None] means never. *)
+
+val set_data_session_gc_frequency : int option -> unit
+(** Set frequency for garbage collection of in memory data sessions.
+    [None] means never. *)
+
+val set_persistent_session_gc_frequency : int option -> unit
+(** Set frequency for garbage collection of persistent data sessions.
+    [None] means never. *)
+
+val set_volatile_timeout :
+   ?scope_hierarchy:Eliom_common.scope_hierarchy
+  -> cookie_level:[< `Session | `Client_process]
+  -> int option
+  -> unit
+
+val set_data_timeout :
+   ?scope_hierarchy:Eliom_common.scope_hierarchy
+  -> cookie_level:[< `Session | `Client_process]
+  -> int option
+  -> unit
+
+val set_service_timeout :
+   ?scope_hierarchy:Eliom_common.scope_hierarchy
+  -> cookie_level:[< `Session | `Client_process]
+  -> int option
+  -> unit
+
+val set_persistent_timeout :
+   ?scope_hierarchy:Eliom_common.scope_hierarchy
+  -> cookie_level:[< `Session | `Client_process]
+  -> int option
+  -> unit
+
+val set_max_service_sessions_per_group : int -> unit
+val set_max_volatile_data_sessions_per_group : int -> unit
+val set_max_persistent_data_sessions_per_group : int -> unit
+val set_max_service_tab_sessions_per_group : int -> unit
+val set_max_volatile_data_tab_sessions_per_group : int -> unit
+val set_max_persistent_data_tab_sessions_per_group : int -> unit
+val set_max_anonymous_services_per_session : int -> unit
+val set_max_volatile_groups_per_site : int -> unit
+val set_secure_cookies : bool -> unit
+val set_application_script : bool * bool -> unit
+val set_cache_global_data : (Eliom_lib.Url.path * int) option -> unit
+val set_html_content_type : string -> unit
+val add_ignored_get_params : string * Re.re -> unit
+val add_ignored_post_params : string * Re.re -> unit
+
+val set_omitpersistentstorage :
+   Eliom_common.omitpersistentstorage_rule list option
+  -> unit
+
 val get_default_hostname : unit -> string
 (** The function [get_default_hostname ()]returns the hostname
-    declared in the config file ([<host defaulthostname="...">]) or
-    the default machine hostname.
-    In that case, absolute URL will use that hostname. *)
+   declared in the config file ([<host defaulthostname="...">]) or
+   the default machine hostname.
+   In that case, absolute URL will use that hostname. *)
 
 val get_default_port : unit -> int
 (** The function [get_default_port ()] returns the port number
-    declared in the config file ([<host defaulthttpport="...">]) or
+   declared in the config file ([<host defaulthttpport="...">]) or
+   -> unit
     80 if undeclared.
 *)
 
