@@ -89,16 +89,15 @@ module Xml : sig
 
   include
     Xml_sigs.Iterable
-      with type 'a wrap = 'a
-       and type 'a list_wrap = 'a list
-       and type event_handler =
-            (Dom_html.event Js.t -> unit) Eliom_client_value.t
-       and type mouse_event_handler =
-            (Dom_html.mouseEvent Js.t -> unit) Eliom_client_value.t
-       and type keyboard_event_handler =
-            (Dom_html.keyboardEvent Js.t -> unit) Eliom_client_value.t
-       and type touch_event_handler =
-            (Dom_html.touchEvent Js.t -> unit) Eliom_client_value.t
+    with type 'a wrap = 'a
+     and type 'a list_wrap = 'a list
+     and type event_handler = (Dom_html.event Js.t -> unit) Eliom_client_value.t
+     and type mouse_event_handler =
+      (Dom_html.mouseEvent Js.t -> unit) Eliom_client_value.t
+     and type keyboard_event_handler =
+      (Dom_html.keyboardEvent Js.t -> unit) Eliom_client_value.t
+     and type touch_event_handler =
+      (Dom_html.touchEvent Js.t -> unit) Eliom_client_value.t
 
   (** {2 Unique nodes } *)
 
@@ -131,8 +130,8 @@ module Xml : sig
   val make_event_handler_table : elt -> Eliom_runtime.RawXML.event_handler_table
   val make_client_attrib_table : elt -> Eliom_runtime.RawXML.client_attrib_table
 
-  val caml_event_handler
-    :  (Dom_html.event Js.t -> unit) Eliom_client_value.t
+  val caml_event_handler :
+     (Dom_html.event Js.t -> unit) Eliom_client_value.t
     -> caml_event_handler
 
   type racontent =
@@ -159,15 +158,15 @@ end
 
 module Xml_shared :
   Xml_sigs.T
-    with type 'a W.t = 'a Eliom_shared.React.S.t
-     and type 'a W.tlist = 'a Eliom_shared.ReactiveData.RList.t
-     and type event_handler = (Dom_html.event Js.t -> unit) Eliom_client_value.t
-     and type mouse_event_handler =
-          (Dom_html.mouseEvent Js.t -> unit) Eliom_client_value.t
-     and type keyboard_event_handler =
-          (Dom_html.keyboardEvent Js.t -> unit) Eliom_client_value.t
-     and type touch_event_handler =
-          (Dom_html.touchEvent Js.t -> unit) Eliom_client_value.t
+  with type 'a W.t = 'a Eliom_shared.React.S.t
+   and type 'a W.tlist = 'a Eliom_shared.ReactiveData.RList.t
+   and type event_handler = (Dom_html.event Js.t -> unit) Eliom_client_value.t
+   and type mouse_event_handler =
+    (Dom_html.mouseEvent Js.t -> unit) Eliom_client_value.t
+   and type keyboard_event_handler =
+    (Dom_html.keyboardEvent Js.t -> unit) Eliom_client_value.t
+   and type touch_event_handler =
+    (Dom_html.touchEvent Js.t -> unit) Eliom_client_value.t
 
 (** Building and pretty-printing valid SVG tree.
 Information about Svg api can be found at {% <<a_api project="tyxml" | module Svg_sigs.T >> %}*)
@@ -183,29 +182,55 @@ module Svg : sig
   type 'a list_wrap = 'a list
   type uri = Xml.uri
 
+  (**/**)
+
+  module Ev' = Eliom_content_core.Svg.Ev'
+
+  (**/**)
+
   (** Typed interface for building valid SVG tree (functional
       semantics). See {% <<a_api project="tyxml" | module
       Svg_sigs.T >> %}. *)
   module F : sig
     (** See {% <<a_api project="tyxml" | module Html_sigs.T >> %}. *)
-    module Raw :
-      Svg_sigs.Make(Xml).T
-        with type +'a elt = 'a elt
-         and type +'a attrib = 'a attrib
 
-    include module type of Raw
+    (**/**)
+
+    module Raw' :
+      Svg_sigs.Make(Xml).T
+      with type +'a elt = 'a elt
+       and type +'a attrib = 'a attrib
+
+    (**/**)
+
+    module Raw : sig
+      include module type of Raw'
+      include module type of Ev' (Raw')
+    end
+
+    include module type of Raw'
   end
 
   (** Typed interface for building valid SVG tree (DOM semantics). See
       {% <<a_api project="tyxml" | module Svg_sigs.T >> %}. *)
   module D : sig
     (** See {% <<a_api project="tyxml" | module Html_sigs.T >> %}. *)
-    module Raw :
-      Svg_sigs.Make(Xml).T
-        with type +'a elt = 'a elt
-         and type +'a attrib = 'a attrib
 
-    include module type of Raw
+    (**/**)
+
+    module Raw' :
+      Svg_sigs.Make(Xml).T
+      with type +'a elt = 'a elt
+       and type +'a attrib = 'a attrib
+
+    (**/**)
+
+    module Raw : sig
+      include module type of Raw'
+      include module type of Ev' (Raw')
+    end
+
+    include module type of Raw'
   end
 
   (** Creation of SVG content from shared reactive signals and data
@@ -215,8 +240,8 @@ module Svg : sig
   module R : sig
     module Raw :
       Svg_sigs.Make(Xml_shared).T
-        with type 'a elt = 'a elt
-         and type 'a attrib = 'a attrib
+      with type 'a elt = 'a elt
+       and type 'a attrib = 'a attrib
 
     include module type of Raw
 
@@ -294,6 +319,12 @@ module Html : sig
   type uri = Xml.uri
   type 'a form_param
 
+  (**/**)
+
+  module Ev' = Eliom_content_core.Html.Ev'
+
+  (**/**)
+
   (** Creation of {b F}unctional HTML5 content (copy-able but not
       referable, see also {% <<a_api|module Eliom_content>> %}). *)
   module F : sig
@@ -307,20 +338,30 @@ module Html : sig
          *)
 
     (** See {% <<a_api project="tyxml" | module Html_sigs.T >> %}. *)
-    module Raw :
-      Html_sigs.Make(Xml)(Svg.F.Raw).T
-        with type +'a elt = 'a elt
-         and type +'a attrib = 'a attrib
 
-    include module type of Raw
+    (**/**)
+
+    module Raw' :
+      Html_sigs.Make(Xml)(Svg.F.Raw').T
+      with type +'a elt = 'a elt
+       and type +'a attrib = 'a attrib
+
+    (**/**)
+
+    module Raw : sig
+      include module type of Raw'
+      include module type of Ev' (Raw')
+    end
+
+    include module type of Raw'
 
     include
       Eliom_content_sigs.LINKS_AND_FORMS
-        with type +'a elt := 'a elt
-         and type +'a attrib := 'a attrib
-         and type uri := uri
-         and type ('a, 'b, 'c) star := ('a, 'b, 'c) star
-         and type 'a form_param := 'a form_param
+      with type +'a elt := 'a elt
+       and type +'a attrib := 'a attrib
+       and type uri := uri
+       and type ('a, 'b, 'c) star := ('a, 'b, 'c) star
+       and type 'a form_param := 'a form_param
   end
 
   (** Creation of HTML content with {b D}OM semantics (referable, see
@@ -335,20 +376,30 @@ module Html : sig
         {% <<a_manual chapter="server-links" fragment="forms"|the manual>> %}. *)
 
     (** See {% <<a_api project="tyxml" | module Html_sigs.T >> %}. *)
-    module Raw :
-      Html_sigs.Make(Xml)(Svg.D.Raw).T
-        with type +'a elt = 'a elt
-         and type +'a attrib = 'a attrib
 
-    include module type of Raw
+    (**/**)
+
+    module Raw' :
+      Html_sigs.Make(Xml)(Svg.D.Raw').T
+      with type +'a elt = 'a elt
+       and type +'a attrib = 'a attrib
+
+    (**/**)
+
+    module Raw : sig
+      include module type of Raw'
+      include module type of Ev' (Raw')
+    end
+
+    include module type of Raw'
 
     include
       Eliom_content_sigs.LINKS_AND_FORMS
-        with type +'a elt := 'a elt
-         and type +'a attrib := 'a attrib
-         and type uri := uri
-         and type ('a, 'b, 'c) star := ('a, 'b, 'c) star
-         and type 'a form_param := 'a form_param
+      with type +'a elt := 'a elt
+       and type +'a attrib := 'a attrib
+       and type uri := uri
+       and type ('a, 'b, 'c) star := ('a, 'b, 'c) star
+       and type 'a form_param := 'a form_param
   end
 
   (** Creation of HTML content from client-side values.  This makes
@@ -414,8 +465,8 @@ module Html : sig
   module R : sig
     include
       Html_sigs.Make(Xml_shared)(Svg.R.Raw).T
-        with type 'a elt = 'a elt
-         and type 'a attrib = 'a attrib
+      with type 'a elt = 'a elt
+       and type 'a attrib = 'a attrib
 
     val pcdata : string Eliom_shared.React.S.t -> [> Html_types.span] elt
     (** [pcdata s] produces a node of type
@@ -438,8 +489,8 @@ module Html : sig
     type 'a t
     (** Custom data with values of type ['a]. *)
 
-    val create
-      :  name:string
+    val create :
+       name:string
       -> ?default:'a
       -> to_string:('a -> string)
       -> of_string:(string -> 'a)
