@@ -25,9 +25,9 @@ open Js_of_ocaml
 module Xml : sig
   module W :
     Xml_wrap.T
-      with type 'a t = 'a
-       and type 'a tlist = 'a list
-       and type (-'a, 'b) ft = 'a -> 'b
+    with type 'a t = 'a
+     and type 'a tlist = 'a list
+     and type (-'a, 'b) ft = 'a -> 'b
 
   type uri = string
 
@@ -42,17 +42,20 @@ module Xml : sig
     | CE_registered_closure of string * Eliom_lib.poly
     (* 'a Js.t -> unit) client_value_server *)
     | CE_client_closure of (Dom_html.event Js.t -> unit) (* Client side-only *)
-    | CE_client_closure_mouse of (Dom_html.mouseEvent Js.t -> unit) (* Client side-only *)
-    | CE_client_closure_keyboard of (Dom_html.keyboardEvent Js.t -> unit) (* Client side-only *)
-    | CE_client_closure_touch of (Dom_html.touchEvent Js.t -> unit) (* Client side-only *)
+    | CE_client_closure_mouse of (Dom_html.mouseEvent Js.t -> unit)
+      (* Client side-only *)
+    | CE_client_closure_keyboard of (Dom_html.keyboardEvent Js.t -> unit)
+      (* Client side-only *)
+    | CE_client_closure_touch of (Dom_html.touchEvent Js.t -> unit)
+      (* Client side-only *)
     | CE_call_service of
         ([`A | `Form_get | `Form_post]
         * (bool * string list) option
         * string option
         * Ocsigen_lib_base.poly)
-        (* (unit -> bool) client_value *)
-        option
-        Eliom_lazy.request
+          (* (unit -> bool) client_value *)
+          option
+          Eliom_lazy.request
 
   type internal_event_handler = Raw of string | Caml of caml_event_handler
   type event_handler = Dom_html.event Js.t -> unit
@@ -75,11 +78,11 @@ module Xml : sig
 
   (**/**)
 
-  val internal_event_handler_of_service
-    :  ([`A | `Form_get | `Form_post]
-       * (bool * string list) option
-       * string option
-       * Eliom_lib.poly)
+  val internal_event_handler_of_service :
+     ([`A | `Form_get | `Form_post]
+     * (bool * string list) option
+     * string option
+     * Eliom_lib.poly)
        option
        Eliom_lazy.request
     -> internal_event_handler
@@ -156,14 +159,14 @@ end
 module Xml_wed : sig
   include
     Xml_sigs.T
-      with module W = Js_of_ocaml_tyxml.Tyxml_js.Wrap
-       and type elt = Xml.elt
-       and type aname = Xml.aname
-       and type attrib = Xml.attrib
-       and type uri = Xml.uri
-       and type 'a W.t = 'a React.signal
-       and type 'a W.tlist = 'a ReactiveData.RList.t
-       and type ('a, 'b) W.ft = 'a -> 'b
+    with module W = Js_of_ocaml_tyxml.Tyxml_js.Wrap
+     and type elt = Xml.elt
+     and type aname = Xml.aname
+     and type attrib = Xml.attrib
+     and type uri = Xml.uri
+     and type 'a W.t = 'a React.signal
+     and type 'a W.tlist = 'a ReactiveData.RList.t
+     and type ('a, 'b) W.ft = 'a -> 'b
 
   val float_attrib : aname -> float React.S.t -> attrib
   val int_attrib : aname -> int React.S.t -> attrib
@@ -188,17 +191,66 @@ module Svg : sig
   type +'a attrib
   type uri = Xml.uri
 
+  (**/**)
+
+  module Ev' (A : sig
+      type 'a attrib
+
+      module Unsafe : sig
+        val string_attrib : string -> string -> 'a attrib
+      end
+    end) : sig
+    val a_onabort : string -> [> `OnAbort] A.attrib
+    val a_onactivate : string -> [> `OnActivate] A.attrib
+    val a_onbegin : string -> [> `OnBegin] A.attrib
+    val a_onend : string -> [> `OnEnd] A.attrib
+    val a_onerror : string -> [> `OnError] A.attrib
+    val a_onfocusin : string -> [> `OnFocusIn] A.attrib
+    val a_onfocusout : string -> [> `OnFocusOut] A.attrib
+
+    val a_onload : string -> [> `OnLoad] A.attrib
+    [@@ocaml.deprecated "Removed in SVG2"]
+    (** @deprecated Removed in SVG2 *)
+
+    val a_onrepeat : string -> [> `OnRepeat] A.attrib
+    val a_onresize : string -> [> `OnResize] A.attrib
+    val a_onscroll : string -> [> `OnScroll] A.attrib
+    val a_onunload : string -> [> `OnUnload] A.attrib
+    val a_onzoom : string -> [> `OnZoom] A.attrib
+    val a_onclick : string -> [> `OnClick] A.attrib
+    val a_onmousedown : string -> [> `OnMouseDown] A.attrib
+    val a_onmouseup : string -> [> `OnMouseUp] A.attrib
+    val a_onmouseover : string -> [> `OnMouseOver] A.attrib
+    val a_onmouseout : string -> [> `OnMouseOut] A.attrib
+    val a_onmousemove : string -> [> `OnMouseMove] A.attrib
+    val a_ontouchstart : string -> [> `OnTouchStart] A.attrib
+    val a_ontouchend : string -> [> `OnTouchEnd] A.attrib
+    val a_ontouchmove : string -> [> `OnTouchMove] A.attrib
+    val a_ontouchcancel : string -> [> `OnTouchCancel] A.attrib
+  end
+
+  (**/**)
+
   (** {2 Functional semantics} *)
 
   (** Typed interface for building valid SVG tree (functional semantics).
       See {% <<a_api project="tyxml" | module type Svg_sigs.T >> %}. *)
   module F : sig
-    module Raw :
-      Svg_sigs.Make(Xml).T
-        with type +'a elt = 'a elt
-         and type +'a attrib = 'a attrib
+    (**/**)
 
-    include module type of Raw
+    module Raw' :
+      Svg_sigs.Make(Xml).T
+      with type +'a elt = 'a elt
+       and type +'a attrib = 'a attrib
+
+    (**/**)
+
+    module Raw : sig
+      include module type of Raw'
+      include module type of Ev' (Raw')
+    end
+
+    include module type of Raw'
     (** See {% <<a_api project="tyxml" | module type Svg_sigs.T >> %}. *)
   end
 
@@ -207,12 +259,21 @@ module Svg : sig
   (** Typed interface for building valid SVG tree (DOM semantics). See
       {% <<a_api project="tyxml" | module type Svg_sigs.T >> %}. *)
   module D : sig
-    module Raw :
-      Svg_sigs.Make(Xml).T
-        with type +'a elt = 'a elt
-         and type +'a attrib = 'a attrib
+    (**/**)
 
-    include module type of Raw
+    module Raw' :
+      Svg_sigs.Make(Xml).T
+      with type +'a elt = 'a elt
+       and type +'a attrib = 'a attrib
+
+    (**/**)
+
+    module Raw : sig
+      include module type of Raw'
+      include module type of Ev' (Raw')
+    end
+
+    include module type of Raw'
     (** See {% <<a_api project="tyxml" | module type Svg_sigs.T >> %}. *)
   end
 
@@ -227,8 +288,8 @@ module Svg : sig
 
     module Raw :
       Svg_sigs.Make(Xml_wed).T
-        with type +'a elt = 'a elt
-         and type +'a attrib = 'a attrib
+      with type +'a elt = 'a elt
+       and type +'a attrib = 'a attrib
 
     include module type of Raw
     (** See {% <<a_api project="tyxml" | module type Svg_sigs.T >> %}. *)
@@ -275,15 +336,111 @@ module Html : sig
   type +'a attrib
   type uri = Xml.uri
 
+  (**/**)
+
+  module Ev' (A : sig
+      type 'a attrib
+
+      module Unsafe : sig
+        val string_attrib : string -> string -> 'a attrib
+      end
+    end) : sig
+    val a_onabort : string -> [> `OnAbort] A.attrib
+    val a_onafterprint : string -> [> `OnAfterPrint] A.attrib
+    val a_onbeforeprint : string -> [> `OnBeforePrint] A.attrib
+    val a_onbeforeunload : string -> [> `OnBeforeUnload] A.attrib
+    val a_onblur : string -> [> `OnBlur] A.attrib
+    val a_oncanplay : string -> [> `OnCanPlay] A.attrib
+    val a_oncanplaythrough : string -> [> `OnCanPlayThrough] A.attrib
+    val a_onchange : string -> [> `OnChange] A.attrib
+    val a_onclose : string -> [> `OnClose] A.attrib
+    val a_ondurationchange : string -> [> `OnDurationChange] A.attrib
+    val a_onemptied : string -> [> `OnEmptied] A.attrib
+    val a_onended : string -> [> `OnEnded] A.attrib
+    val a_onerror : string -> [> `OnError] A.attrib
+    val a_onfocus : string -> [> `OnFocus] A.attrib
+    val a_onformchange : string -> [> `OnFormChange] A.attrib
+    val a_onforminput : string -> [> `OnFormInput] A.attrib
+    val a_onhashchange : string -> [> `OnHashChange] A.attrib
+    val a_oninput : string -> [> `OnInput] A.attrib
+    val a_oninvalid : string -> [> `OnInvalid] A.attrib
+    val a_onmousewheel : string -> [> `OnMouseWheel] A.attrib
+    val a_onoffline : string -> [> `OnOffLine] A.attrib
+    val a_ononline : string -> [> `OnOnLine] A.attrib
+    val a_onpause : string -> [> `OnPause] A.attrib
+    val a_onplay : string -> [> `OnPlay] A.attrib
+    val a_onplaying : string -> [> `OnPlaying] A.attrib
+    val a_onpagehide : string -> [> `OnPageHide] A.attrib
+    val a_onpageshow : string -> [> `OnPageShow] A.attrib
+    val a_onpopstate : string -> [> `OnPopState] A.attrib
+    val a_onprogress : string -> [> `OnProgress] A.attrib
+    val a_onratechange : string -> [> `OnRateChange] A.attrib
+    val a_onreadystatechange : string -> [> `OnReadyStateChange] A.attrib
+    val a_onredo : string -> [> `OnRedo] A.attrib
+    val a_onresize : string -> [> `OnResize] A.attrib
+    val a_onscroll : string -> [> `OnScroll] A.attrib
+    val a_onseeked : string -> [> `OnSeeked] A.attrib
+    val a_onseeking : string -> [> `OnSeeking] A.attrib
+    val a_onselect : string -> [> `OnSelect] A.attrib
+    val a_onshow : string -> [> `OnShow] A.attrib
+    val a_onstalled : string -> [> `OnStalled] A.attrib
+    val a_onstorage : string -> [> `OnStorage] A.attrib
+    val a_onsubmit : string -> [> `OnSubmit] A.attrib
+    val a_onsuspend : string -> [> `OnSuspend] A.attrib
+    val a_ontimeupdate : string -> [> `OnTimeUpdate] A.attrib
+    val a_onundo : string -> [> `OnUndo] A.attrib
+    val a_onunload : string -> [> `OnUnload] A.attrib
+    val a_onvolumechange : string -> [> `OnVolumeChange] A.attrib
+    val a_onwaiting : string -> [> `OnWaiting] A.attrib
+    val a_onload : string -> [> `OnLoad] A.attrib
+    val a_onloadeddata : string -> [> `OnLoadedData] A.attrib
+    val a_onloadedmetadata : string -> [> `OnLoadedMetaData] A.attrib
+    val a_onloadstart : string -> [> `OnLoadStart] A.attrib
+    val a_onmessage : string -> [> `OnMessage] A.attrib
+    val a_onclick : string -> [> `OnClick] A.attrib
+    val a_oncontextmenu : string -> [> `OnContextMenu] A.attrib
+    val a_ondblclick : string -> [> `OnDblClick] A.attrib
+    val a_ondrag : string -> [> `OnDrag] A.attrib
+    val a_ondragend : string -> [> `OnDragEnd] A.attrib
+    val a_ondragenter : string -> [> `OnDragEnter] A.attrib
+    val a_ondragleave : string -> [> `OnDragLeave] A.attrib
+    val a_ondragover : string -> [> `OnDragOver] A.attrib
+    val a_ondragstart : string -> [> `OnDragStart] A.attrib
+    val a_ondrop : string -> [> `OnDrop] A.attrib
+    val a_onmousedown : string -> [> `OnMouseDown] A.attrib
+    val a_onmouseup : string -> [> `OnMouseUp] A.attrib
+    val a_onmouseover : string -> [> `OnMouseOver] A.attrib
+    val a_onmousemove : string -> [> `OnMouseMove] A.attrib
+    val a_onmouseout : string -> [> `OnMouseOut] A.attrib
+    val a_ontouchstart : string -> [> `OnTouchStart] A.attrib
+    val a_ontouchend : string -> [> `OnTouchEnd] A.attrib
+    val a_ontouchmove : string -> [> `OnTouchMove] A.attrib
+    val a_ontouchcancel : string -> [> `OnTouchCancel] A.attrib
+    val a_onkeypress : string -> [> `OnKeyPress] A.attrib
+    val a_onkeydown : string -> [> `OnKeyDown] A.attrib
+    val a_onkeyup : string -> [> `OnKeyUp] A.attrib
+  end
+
+  (**/**)
+
   (** Typed interface for building valid HTML5 tree (functional semantics).
       See {% <<a_api project="tyxml" | module type Html_sigs.T >> %}. *)
   module F : sig
-    module Raw :
-      Html_sigs.Make(Xml)(Svg.F.Raw).T
-        with type +'a elt = 'a elt
-         and type +'a attrib = 'a attrib
+    (**/**)
 
-    include module type of Raw
+    module Raw' :
+      Html_sigs.Make(Xml)(Svg.F.Raw').T
+      with type +'a elt = 'a elt
+       and type +'a attrib = 'a attrib
+
+    (**/**)
+
+    module Raw : sig
+      include module type of Raw'
+      include module type of Ev' (Raw')
+    end
+
+    include module type of Raw'
     (** See {% <<a_api project="tyxml" | module type Html_sigs.T >> %}. *)
 
     (*BB TODO Hide untyped [input]. *)
@@ -293,8 +450,8 @@ module Html : sig
     type ('a, 'b, 'c) lazy_star =
       ?a:'a attrib list -> 'b elt list Eliom_lazy.request -> 'c elt
 
-    val lazy_form
-      : ( [< Html_types.form_attrib]
+    val lazy_form :
+      ( [< Html_types.form_attrib]
         , [< Html_types.form_content_fun]
         , [> Html_types.form] )
         lazy_star
@@ -303,20 +460,29 @@ module Html : sig
   (** Typed interface for building valid HTML5 tree (DOM semantics). See
       {% <<a_api project="tyxml" | module type Html_sigs.T >> %}. *)
   module D : sig
-    module Raw :
-      Html_sigs.Make(Xml)(Svg.D.Raw).T
-        with type +'a elt = 'a elt
-         and type +'a attrib = 'a attrib
+    (**/**)
 
-    include module type of Raw
+    module Raw' :
+      Html_sigs.Make(Xml)(Svg.D.Raw').T
+      with type +'a elt = 'a elt
+       and type +'a attrib = 'a attrib
+
+    (**/**)
+
+    module Raw : sig
+      include module type of Raw'
+      include module type of Ev' (Raw')
+    end
+
+    include module type of Raw'
 
     (**/**)
 
     type ('a, 'b, 'c) lazy_star =
       ?a:'a attrib list -> 'b elt list Eliom_lazy.request -> 'c elt
 
-    val lazy_form
-      : ( [< Html_types.form_attrib]
+    val lazy_form :
+      ( [< Html_types.form_attrib]
         , [< Html_types.form_content_fun]
         , [> Html_types.form] )
         lazy_star
@@ -338,8 +504,8 @@ module Html : sig
 
     module Raw :
       Html_sigs.Make(Xml_wed)(Svg.R.Raw).T
-        with type +'a elt = 'a elt
-         and type +'a attrib = 'a attrib
+      with type +'a elt = 'a elt
+       and type +'a attrib = 'a attrib
 
     include module type of Raw
   end
@@ -377,8 +543,8 @@ module Html : sig
     type 'a t
     (** Custom data with values of type ['a]. *)
 
-    val create
-      :  name:string
+    val create :
+       name:string
       -> ?default:'a
       -> to_string:('a -> string)
       -> of_string:(string -> 'a)
