@@ -25,8 +25,8 @@ module type PARAM = sig
   type result
   type frame
 
-  val send
-    :  ?options:options
+  val send :
+     ?options:options
     -> ?charset:string
     -> ?code:int
     -> ?content_type:string
@@ -49,8 +49,8 @@ module type PARAM_POLY = sig
   type _ return
   type frame
 
-  val send
-    :  ?options:options
+  val send :
+     ?options:options
     -> ?charset:string
     -> ?code:int
     -> ?content_type:string
@@ -82,8 +82,8 @@ module type S = sig
 
   (** {2 Service registration } *)
 
-  val register
-    :  ?app:string
+  val register :
+     ?app:string
     -> ?scope:[< Eliom_common.scope]
     -> ?options:options
     -> ?charset:string
@@ -93,17 +93,17 @@ module type S = sig
     -> ?secure_session:bool
     -> service:
          ( 'get
-         , 'post
-         , _
-         , _
-         , _
-         , Eliom_service.non_ext
-         , Eliom_service.reg
-         , _
-         , _
-         , _
-         , return )
-         Eliom_service.t
+           , 'post
+           , _
+           , _
+           , _
+           , Eliom_service.non_ext
+           , Eliom_service.reg
+           , _
+           , _
+           , _
+           , return )
+           Eliom_service.t
     -> ?error_handler:((string * exn) list -> page Lwt.t)
     -> ('get -> 'post -> page Lwt.t)
     -> unit
@@ -140,8 +140,8 @@ module type S = sig
       expected type. The default error handler is [ fun l -> raise
       (]{!Eliom_common.Eliom_Typing_Error}[ l) ]. *)
 
-  val send
-    :  ?options:options
+  val send :
+     ?options:options
     -> ?charset:string
     -> ?code:int
     -> ?content_type:string
@@ -157,8 +157,8 @@ end
 module type S_with_create = sig
   include S
 
-  val create
-    :  ?app:string
+  val create :
+     ?app:string
     -> ?scope:[< Eliom_common.scope]
     -> ?options:options
     -> ?charset:string
@@ -178,24 +178,24 @@ module type S_with_create = sig
     -> ?error_handler:((string * exn) list -> page Lwt.t)
     -> ('gp -> 'pp -> page Lwt.t)
     -> ( 'gp
-       , 'pp
-       , 'm
-       , 'att
-       , 'co
-       , Eliom_service.non_ext
-       , Eliom_service.reg
-       , 'tipo
-       , 'gn
-       , 'pn
-       , return )
-       Eliom_service.t
+         , 'pp
+         , 'm
+         , 'att
+         , 'co
+         , Eliom_service.non_ext
+         , Eliom_service.reg
+         , 'tipo
+         , 'gn
+         , 'pn
+         , return )
+         Eliom_service.t
   (** Create a service and register it at the same time.
       It calls {!Eliom_service.create} and then performs
       {!Eliom_registration_sigs.S.register}.
       Returns the service. *)
 
-  val create_attached_get
-    :  ?app:string
+  val create_attached_get :
+     ?app:string
     -> ?scope:[< Eliom_common.scope]
     -> ?options:options
     -> ?charset:string
@@ -212,39 +212,39 @@ module type S_with_create = sig
     -> ?timeout:float
     -> fallback:
          ( unit
-         , unit
-         , Eliom_service.get
-         , Eliom_service.att
-         , Eliom_service.non_co
-         , Eliom_service.non_ext
-         , _
-         , [`WithoutSuffix]
-         , unit
-         , unit
-         , return )
-         Eliom_service.t
+           , unit
+           , Eliom_service.get
+           , Eliom_service.att
+           , Eliom_service.non_co
+           , Eliom_service.non_ext
+           , _
+           , [`WithoutSuffix]
+           , unit
+           , unit
+           , return )
+           Eliom_service.t
     -> get_params:('gp, [`WithoutSuffix], 'gn) Eliom_parameter.params_type
     -> ?error_handler:((string * exn) list -> page Lwt.t)
     -> ('gp -> unit -> page Lwt.t)
     -> ( 'gp
-       , unit
-       , Eliom_service.get
-       , Eliom_service.att
-       , Eliom_service.co
-       , Eliom_service.non_ext
-       , Eliom_service.reg
-       , [`WithoutSuffix]
-       , 'gn
-       , unit
-       , return )
-       Eliom_service.t
+         , unit
+         , Eliom_service.get
+         , Eliom_service.att
+         , Eliom_service.co
+         , Eliom_service.non_ext
+         , Eliom_service.reg
+         , [`WithoutSuffix]
+         , 'gn
+         , unit
+         , return )
+         Eliom_service.t
   (** Create an attached service and register it at the same time.
       It calls {!Eliom_service.create_attached_get} and then performs
       {!Eliom_registration_sigs.S.register}.
       Returns the new service. *)
 
-  val create_attached_post
-    :  ?app:string
+  val create_attached_post :
+     ?app:string
     -> ?scope:[< Eliom_common.scope]
     -> ?options:options
     -> ?charset:string
@@ -261,32 +261,32 @@ module type S_with_create = sig
     -> ?timeout:float
     -> fallback:
          ( 'gp
-         , unit
-         , Eliom_service.get
-         , Eliom_service.att
-         , Eliom_service.non_co
-         , Eliom_service.non_ext
-         , _
-         , [`WithoutSuffix]
-         , 'gn
-         , unit
-         , return )
-         Eliom_service.t
+           , unit
+           , Eliom_service.get
+           , Eliom_service.att
+           , Eliom_service.non_co
+           , Eliom_service.non_ext
+           , _
+           , [`WithoutSuffix]
+           , 'gn
+           , unit
+           , return )
+           Eliom_service.t
     -> post_params:('pp, [`WithoutSuffix], 'pn) Eliom_parameter.params_type
     -> ?error_handler:((string * exn) list -> page Lwt.t)
     -> ('gp -> 'pp -> page Lwt.t)
     -> ( 'gp
-       , 'pp
-       , Eliom_service.post
-       , Eliom_service.att
-       , Eliom_service.co
-       , Eliom_service.non_ext
-       , Eliom_service.reg
-       , [`WithoutSuffix]
-       , 'gn
-       , 'pn
-       , return )
-       Eliom_service.t
+         , 'pp
+         , Eliom_service.post
+         , Eliom_service.att
+         , Eliom_service.co
+         , Eliom_service.non_ext
+         , Eliom_service.reg
+         , [`WithoutSuffix]
+         , 'gn
+         , 'pn
+         , return )
+         Eliom_service.t
   (** Create an attached POST service and register it at the same time.
       It calls {!Eliom_service.create_attached_post} and then performs
       {!Eliom_registration_sigs.S.register}.
@@ -298,8 +298,8 @@ module type S_poly = sig
   type options
   type _ return
 
-  val register
-    :  ?app:string
+  val register :
+     ?app:string
     -> ?scope:[< Eliom_common.scope]
     -> ?options:options
     -> ?charset:string
@@ -309,17 +309,17 @@ module type S_poly = sig
     -> ?secure_session:bool
     -> service:
          ( 'get
-         , 'post
-         , _
-         , _
-         , _
-         , Eliom_service.non_ext
-         , Eliom_service.reg
-         , _
-         , _
-         , _
-         , 'a return )
-         Eliom_service.t
+           , 'post
+           , _
+           , _
+           , _
+           , Eliom_service.non_ext
+           , Eliom_service.reg
+           , _
+           , _
+           , _
+           , 'a return )
+           Eliom_service.t
     -> ?error_handler:((string * exn) list -> 'a page Lwt.t)
     -> ('get -> 'post -> 'a page Lwt.t)
     -> unit
@@ -329,8 +329,8 @@ end
 module type S_poly_with_create = sig
   include S_poly
 
-  val create
-    :  ?app:string
+  val create :
+     ?app:string
     -> ?scope:[< Eliom_common.scope]
     -> ?options:options
     -> ?charset:string
@@ -350,21 +350,21 @@ module type S_poly_with_create = sig
     -> ?error_handler:((string * exn) list -> 'a page Lwt.t)
     -> ('gp -> 'pp -> 'a page Lwt.t)
     -> ( 'gp
-       , 'pp
-       , 'm
-       , 'att
-       , 'co
-       , Eliom_service.non_ext
-       , Eliom_service.reg
-       , 'tipo
-       , 'gn
-       , 'pn
-       , 'a return )
-       Eliom_service.t
+         , 'pp
+         , 'm
+         , 'att
+         , 'co
+         , Eliom_service.non_ext
+         , Eliom_service.reg
+         , 'tipo
+         , 'gn
+         , 'pn
+         , 'a return )
+         Eliom_service.t
   (** See {!S_with_create.create}. *)
 
-  val create_attached_get
-    :  ?app:string
+  val create_attached_get :
+     ?app:string
     -> ?scope:[< Eliom_common.scope]
     -> ?options:options
     -> ?charset:string
@@ -381,36 +381,36 @@ module type S_poly_with_create = sig
     -> ?timeout:float
     -> fallback:
          ( unit
-         , unit
-         , Eliom_service.get
-         , Eliom_service.att
-         , Eliom_service.non_co
-         , Eliom_service.non_ext
-         , _
-         , [`WithoutSuffix]
-         , unit
-         , unit
-         , 'a return )
-         Eliom_service.t
+           , unit
+           , Eliom_service.get
+           , Eliom_service.att
+           , Eliom_service.non_co
+           , Eliom_service.non_ext
+           , _
+           , [`WithoutSuffix]
+           , unit
+           , unit
+           , 'a return )
+           Eliom_service.t
     -> get_params:('gp, [`WithoutSuffix], 'gn) Eliom_parameter.params_type
     -> ?error_handler:((string * exn) list -> 'a page Lwt.t)
     -> ('gp -> unit -> 'a page Lwt.t)
     -> ( 'gp
-       , unit
-       , Eliom_service.get
-       , Eliom_service.att
-       , Eliom_service.co
-       , Eliom_service.non_ext
-       , Eliom_service.reg
-       , [`WithoutSuffix]
-       , 'gn
-       , unit
-       , 'a return )
-       Eliom_service.t
+         , unit
+         , Eliom_service.get
+         , Eliom_service.att
+         , Eliom_service.co
+         , Eliom_service.non_ext
+         , Eliom_service.reg
+         , [`WithoutSuffix]
+         , 'gn
+         , unit
+         , 'a return )
+         Eliom_service.t
   (** See {!S_with_create.create_attached_get}. *)
 
-  val create_attached_post
-    :  ?app:string
+  val create_attached_post :
+     ?app:string
     -> ?scope:[< Eliom_common.scope]
     -> ?options:options
     -> ?charset:string
@@ -427,32 +427,32 @@ module type S_poly_with_create = sig
     -> ?timeout:float
     -> fallback:
          ( 'gp
-         , unit
-         , Eliom_service.get
-         , Eliom_service.att
-         , Eliom_service.non_co
-         , Eliom_service.non_ext
-         , _
-         , [`WithoutSuffix]
-         , 'gn
-         , unit
-         , 'a return )
-         Eliom_service.t
+           , unit
+           , Eliom_service.get
+           , Eliom_service.att
+           , Eliom_service.non_co
+           , Eliom_service.non_ext
+           , _
+           , [`WithoutSuffix]
+           , 'gn
+           , unit
+           , 'a return )
+           Eliom_service.t
     -> post_params:('pp, [`WithoutSuffix], 'pn) Eliom_parameter.params_type
     -> ?error_handler:((string * exn) list -> 'a page Lwt.t)
     -> ('gp -> 'pp -> 'a page Lwt.t)
     -> ( 'gp
-       , 'pp
-       , Eliom_service.post
-       , Eliom_service.att
-       , Eliom_service.co
-       , Eliom_service.non_ext
-       , Eliom_service.reg
-       , [`WithoutSuffix]
-       , 'gn
-       , 'pn
-       , 'a return )
-       Eliom_service.t
+         , 'pp
+         , Eliom_service.post
+         , Eliom_service.att
+         , Eliom_service.co
+         , Eliom_service.non_ext
+         , Eliom_service.reg
+         , [`WithoutSuffix]
+         , 'gn
+         , 'pn
+         , 'a return )
+         Eliom_service.t
   (** See {!S_with_create.create_attached_post}. *)
 end
 
@@ -461,8 +461,8 @@ module type S_poly_with_send = sig
 
   type 'a result
 
-  val send
-    :  ?options:options
+  val send :
+     ?options:options
     -> ?charset:string
     -> ?code:int
     -> ?content_type:string
@@ -476,8 +476,8 @@ module type S_poly_with_create_with_send = sig
 
   type 'a result
 
-  val send
-    :  ?options:options
+  val send :
+     ?options:options
     -> ?charset:string
     -> ?code:int
     -> ?content_type:string
