@@ -29,8 +29,8 @@
     of shared functions, i.e., functions that have both a client-side
     and a server-side implementation. *)
 
-val to_signal
-  :  init:'a
+val to_signal :
+   init:'a
   -> ?eq:('a -> 'a -> bool)
   -> 'a React.S.t Lwt.t
   -> 'a React.S.t
@@ -45,9 +45,9 @@ module React : sig
   module S : sig
     include Eliom_shared_sigs.S with type 'a sv := 'a Value.t
 
-    val create
-      :  ?default:
-           ('a React.S.t * (?step:React.step -> 'a -> unit)) option
+    val create :
+       ?default:
+         ('a React.S.t * (?step:React.step -> 'a -> unit)) option
            Eliom_client_value.t
       -> ?reset_default:bool
       -> ?eq:('a -> 'a -> bool) Value.t
@@ -89,10 +89,10 @@ module ReactiveData : sig
   module RList : sig
     include
       Eliom_shared_sigs.RLIST
-        with type 'a signal := 'a React.S.t
-         and type 'a sv := 'a Value.t
-         and type 'a ct := 'a FakeReactiveData.RList.t
-         and type 'a chandle := 'a FakeReactiveData.RList.handle
+      with type 'a signal := 'a React.S.t
+       and type 'a sv := 'a Value.t
+       and type 'a ct := 'a FakeReactiveData.RList.t
+       and type 'a chandle := 'a FakeReactiveData.RList.handle
 
     val synced : 'a t -> bool
     (** If [synced l] is true, then the server-side and client-side
