@@ -39,37 +39,37 @@ module type S = sig
   val value : 'a t -> 'a sv
   val map : ?eq:('b -> 'b -> bool) sv -> ('a -> 'b) sv -> 'a t -> 'b t
 
-  val fmap
-    :  ?eq:('b -> 'b -> bool) sv
+  val fmap :
+     ?eq:('b -> 'b -> bool) sv
     -> ('a -> 'b option) sv
     -> 'b sv
     -> 'a t
     -> 'b t
 
-  val merge
-    :  ?eq:('a -> 'a -> bool) sv
+  val merge :
+     ?eq:('a -> 'a -> bool) sv
     -> ('a -> 'b -> 'a) sv
     -> 'a
     -> 'b t list
     -> 'a t
 
-  val l2
-    :  ?eq:('c -> 'c -> bool) sv
+  val l2 :
+     ?eq:('c -> 'c -> bool) sv
     -> ('a -> 'b -> 'c) sv
     -> 'a t
     -> 'b t
     -> 'c t
 
-  val l3
-    :  ?eq:('d -> 'd -> bool) sv
+  val l3 :
+     ?eq:('d -> 'd -> bool) sv
     -> ('a -> 'b -> 'c -> 'd) sv
     -> 'a t
     -> 'b t
     -> 'c t
     -> 'd t
 
-  val l4
-    :  ?eq:('e -> 'e -> bool) sv
+  val l4 :
+     ?eq:('e -> 'e -> bool) sv
     -> ('a -> 'b -> 'c -> 'd -> 'e) sv
     -> 'a t
     -> 'b t
@@ -77,8 +77,8 @@ module type S = sig
     -> 'd t
     -> 'e t
 
-  val l5
-    :  ?eq:('f -> 'f -> bool) sv
+  val l5 :
+     ?eq:('f -> 'f -> bool) sv
     -> ('a -> 'b -> 'c -> 'd -> 'e -> 'f) sv
     -> 'a t
     -> 'b t
@@ -87,8 +87,8 @@ module type S = sig
     -> 'e t
     -> 'f t
 
-  val l6
-    :  ?eq:('g -> 'g -> bool) sv
+  val l6 :
+     ?eq:('g -> 'g -> bool) sv
     -> ('a -> 'b -> 'c -> 'd -> 'e -> 'f -> 'g) sv
     -> 'a t
     -> 'b t
@@ -111,29 +111,29 @@ module type S = sig
 
   (** Cooperative versions of the React operators *)
   module Lwt : sig
-    val map_s
-      :  ?eq:('b -> 'b -> bool) sv
+    val map_s :
+       ?eq:('b -> 'b -> bool) sv
       -> ('a -> 'b Lwt.t) sv
       -> 'a t
       -> 'b t Lwt.t
 
-    val l2_s
-      :  ?eq:('c -> 'c -> bool) sv
+    val l2_s :
+       ?eq:('c -> 'c -> bool) sv
       -> ('a -> 'b -> 'c Lwt.t) sv
       -> 'a t
       -> 'b t
       -> 'c t Lwt.t
 
-    val l3_s
-      :  ?eq:('d -> 'd -> bool) sv
+    val l3_s :
+       ?eq:('d -> 'd -> bool) sv
       -> ('a -> 'b -> 'c -> 'd Lwt.t) sv
       -> 'a t
       -> 'b t
       -> 'c t
       -> 'd t Lwt.t
 
-    val l4_s
-      :  ?eq:('e -> 'e -> bool) sv
+    val l4_s :
+       ?eq:('e -> 'e -> bool) sv
       -> ('a -> 'b -> 'c -> 'd -> 'e Lwt.t) sv
       -> 'a t
       -> 'b t
@@ -141,8 +141,8 @@ module type S = sig
       -> 'd t
       -> 'e t Lwt.t
 
-    val l5_s
-      :  ?eq:('f -> 'f -> bool) sv
+    val l5_s :
+       ?eq:('f -> 'f -> bool) sv
       -> ('a -> 'b -> 'c -> 'd -> 'e -> 'f Lwt.t) sv
       -> 'a t
       -> 'b t
@@ -151,8 +151,8 @@ module type S = sig
       -> 'e t
       -> 'f t Lwt.t
 
-    val l6_s
-      :  ?eq:('g -> 'g -> bool) sv
+    val l6_s :
+       ?eq:('g -> 'g -> bool) sv
       -> ('a -> 'b -> 'c -> 'd -> 'e -> 'f -> 'g Lwt.t) sv
       -> 'a t
       -> 'b t
@@ -162,8 +162,8 @@ module type S = sig
       -> 'f t
       -> 'g t Lwt.t
 
-    val merge_s
-      :  ?eq:('a -> 'a -> bool) sv
+    val merge_s :
+       ?eq:('a -> 'a -> bool) sv
       -> ('a -> 'b -> 'a Lwt.t) sv
       -> 'a
       -> 'b t list
@@ -189,8 +189,8 @@ module type RLIST = sig
   type 'a chandle
   (** Client-side version of 'a handle *)
 
-  val create
-    :  ?default:('a ct * 'a chandle) option Eliom_client_value.t
+  val create :
+     ?default:('a ct * 'a chandle) option Eliom_client_value.t
     -> ?reset_default:bool
     -> 'a list
     -> 'a t * 'a handle
@@ -210,8 +210,8 @@ module type RLIST = sig
   val map : ('a -> 'b) sv -> 'a t -> 'b t
   val from_signal : ?eq:('a -> 'a -> bool) sv -> 'a list signal -> 'a t
 
-  val acc_e
-    :  ?init:'a t * 'a handle
+  val acc_e :
+     ?init:'a t * 'a handle
     -> 'a React.E.t Eliom_client_value.t
     -> 'a t
 
