@@ -32,8 +32,8 @@
 
 (** {3 Closing sessions, removing state data and services} *)
 
-val discard
-  :  scope:[< Eliom_common.user_scope | Eliom_common.request_scope]
+val discard :
+   scope:[< Eliom_common.user_scope | Eliom_common.request_scope]
   -> ?secure:bool
   -> unit
   -> unit Lwt.t
@@ -57,8 +57,8 @@ val discard
    for all user and request scopes *)
 val discard_all_scopes : ?secure:bool -> unit -> unit Lwt.t
 
-val discard_data
-  :  ?persistent:bool
+val discard_data :
+   ?persistent:bool
   -> scope:[< Eliom_common.user_scope | Eliom_common.request_scope]
   -> ?secure:bool
   -> unit
@@ -70,8 +70,8 @@ val discard_data
     or persistent data.
  *)
 
-val discard_services
-  :  scope:[< Eliom_common.user_scope]
+val discard_services :
+   scope:[< Eliom_common.user_scope]
   -> ?secure:bool
   -> unit
   -> unit
@@ -93,20 +93,20 @@ val discard_services
 
 type state_status = Alive_state | Empty_state | Expired_state
 
-val service_state_status
-  :  scope:[< Eliom_common.user_scope]
+val service_state_status :
+   scope:[< Eliom_common.user_scope]
   -> ?secure:bool
   -> unit
   -> state_status
 
-val volatile_data_state_status
-  :  scope:[< Eliom_common.user_scope]
+val volatile_data_state_status :
+   scope:[< Eliom_common.user_scope]
   -> ?secure:bool
   -> unit
   -> state_status
 
-val persistent_data_state_status
-  :  scope:[< Eliom_common.user_scope]
+val persistent_data_state_status :
+   scope:[< Eliom_common.user_scope]
   -> ?secure:bool
   -> unit
   -> state_status Lwt.t
@@ -134,8 +134,8 @@ val persistent_data_state_status
     Secure cookies are sent by the browser only with HTTPS (default: [false]).
 *)
 
-val set_cookie
-  :  ?cookie_level:Eliom_common.cookie_level
+val set_cookie :
+   ?cookie_level:Eliom_common.cookie_level
   -> ?path:string list
   -> ?exp:float
   -> ?secure:bool
@@ -145,8 +145,8 @@ val set_cookie
   -> unit
 (** Ask the browser to record a cookie. *)
 
-val unset_cookie
-  :  ?cookie_level:Eliom_common.cookie_level
+val unset_cookie :
+   ?cookie_level:Eliom_common.cookie_level
   -> ?path:string list
   -> name:string
   -> unit
@@ -169,8 +169,8 @@ val unset_cookie
 
 (** {3 Putting a session in a group, removing a session from a group} *)
 
-val set_service_session_group
-  :  ?set_max:int
+val set_service_session_group :
+   ?set_max:int
   -> ?scope:Eliom_common.session_scope
   -> ?secure:bool
   -> string
@@ -186,8 +186,8 @@ val set_service_session_group
     otherwise (default), the unsecure one (behavior change in Eliom 4).
 *)
 
-val unset_service_session_group
-  :  ?set_max:int
+val unset_service_session_group :
+   ?set_max:int
   -> ?scope:Eliom_common.session_scope
   -> ?secure:bool
   -> unit
@@ -195,8 +195,8 @@ val unset_service_session_group
 (** Remove the session from its group.
     Will not close the session if it contains data. *)
 
-val get_service_session_group
-  :  ?scope:Eliom_common.session_scope
+val get_service_session_group :
+   ?scope:Eliom_common.session_scope
   -> ?secure:bool
   -> unit
   -> string option
@@ -205,16 +205,16 @@ val get_service_session_group
     or if no session is opened, return [None].
 *)
 
-val get_service_session_group_size
-  :  ?scope:Eliom_common.session_scope
+val get_service_session_group_size :
+   ?scope:Eliom_common.session_scope
   -> ?secure:bool
   -> unit
   -> int option
 (** returns the number of sessions in the group. If he session does not
     belong to any group or if no session is opened, returns [None] *)
 
-val set_volatile_data_session_group
-  :  ?set_max:int
+val set_volatile_data_session_group :
+   ?set_max:int
   -> ?scope:Eliom_common.session_scope
   -> ?secure:bool
   -> string
@@ -227,8 +227,8 @@ val set_volatile_data_session_group
     or default configuration if the group does not exist.
 *)
 
-val unset_volatile_data_session_group
-  :  ?set_max:int
+val unset_volatile_data_session_group :
+   ?set_max:int
   -> ?scope:Eliom_common.session_scope
   -> ?secure:bool
   -> unit
@@ -236,8 +236,8 @@ val unset_volatile_data_session_group
 (** Remove the session from its group.
     Will not close the session if it contains data. *)
 
-val get_volatile_data_session_group
-  :  ?scope:Eliom_common.session_scope
+val get_volatile_data_session_group :
+   ?scope:Eliom_common.session_scope
   -> ?secure:bool
   -> unit
   -> string option
@@ -246,16 +246,16 @@ val get_volatile_data_session_group
     return [None].
 *)
 
-val get_volatile_data_session_group_size
-  :  ?scope:Eliom_common.session_scope
+val get_volatile_data_session_group_size :
+   ?scope:Eliom_common.session_scope
   -> ?secure:bool
   -> unit
   -> int option
 (** returns the number of sessions in the group. If he session does not
     belong to any group or if no session is opened, returns [None] *)
 
-val set_persistent_data_session_group
-  :  ?set_max:int option
+val set_persistent_data_session_group :
+   ?set_max:int option
   -> ?scope:Eliom_common.session_scope
   -> ?secure:bool
   -> string
@@ -269,16 +269,16 @@ val set_persistent_data_session_group
     the group does not exist.
 *)
 
-val unset_persistent_data_session_group
-  :  ?scope:Eliom_common.session_scope
+val unset_persistent_data_session_group :
+   ?scope:Eliom_common.session_scope
   -> ?secure:bool
   -> unit
   -> unit Lwt.t
 (** Remove the session from its group.
     Will not close the session if it contains data. *)
 
-val get_persistent_data_session_group
-  :  ?scope:Eliom_common.session_scope
+val get_persistent_data_session_group :
+   ?scope:Eliom_common.session_scope
   -> ?secure:bool
   -> unit
   -> string option Lwt.t
@@ -321,86 +321,86 @@ val get_persistent_data_session_group
     (for example in the site configuration Web interface).
 *)
 
-val set_default_max_service_sessions_per_group
-  :  ?override_configfile:bool
+val set_default_max_service_sessions_per_group :
+   ?override_configfile:bool
   -> int
   -> unit
 (** Sets the maximum number of service sessions in a session group
     (see above).
 *)
 
-val set_default_max_volatile_data_sessions_per_group
-  :  ?override_configfile:bool
+val set_default_max_volatile_data_sessions_per_group :
+   ?override_configfile:bool
   -> int
   -> unit
 (** Sets the maximum number of volatile data sessions in a session
     group (see above).
 *)
 
-val set_default_max_persistent_data_sessions_per_group
-  :  ?override_configfile:bool
+val set_default_max_persistent_data_sessions_per_group :
+   ?override_configfile:bool
   -> int option
   -> unit
 (** Sets the maximum number of persistent data sessions in a session
     group (see above). [None] means "no limitation".
 *)
 
-val set_default_max_volatile_sessions_per_group
-  :  ?override_configfile:bool
+val set_default_max_volatile_sessions_per_group :
+   ?override_configfile:bool
   -> int
   -> unit
 (** Sets the maximum number of volatile sessions (data and service) in a session
     group (see above).
 *)
 
-val set_default_max_service_sessions_per_subnet
-  :  ?override_configfile:bool
+val set_default_max_service_sessions_per_subnet :
+   ?override_configfile:bool
   -> int
   -> unit
 (** Sets the maximum number of service sessions in a subnet (see above).
 *)
 
-val set_default_max_volatile_data_sessions_per_subnet
-  :  ?override_configfile:bool
+val set_default_max_volatile_data_sessions_per_subnet :
+   ?override_configfile:bool
   -> int
   -> unit
 (** Sets the maximum number of volatile data sessions in a subnet (see above).
 *)
 
-val set_default_max_volatile_sessions_per_subnet
-  :  ?override_configfile:bool
+val set_default_max_volatile_sessions_per_subnet :
+   ?override_configfile:bool
   -> int
   -> unit
 (** Sets the maximum number of volatile sessions (data and service)
     in a subnet (see above).
 *)
 
-val set_default_max_service_tab_sessions_per_group
-  :  ?override_configfile:bool
+val set_default_max_service_tab_sessions_per_group :
+   ?override_configfile:bool
   -> int
   -> unit
 (** Sets the maximum number of tab service sessions in a session group
     (see above).
 *)
 
-val set_default_max_volatile_data_tab_sessions_per_group
-  :  ?override_configfile:bool
+val set_default_max_volatile_data_tab_sessions_per_group :
+   ?override_configfile:bool
   -> int
   -> unit
 (** Sets the maximum number of volatile data tab sessions in a session
     group (see above).
 *)
 
-val set_default_max_persistent_data_tab_sessions_per_group
-  :  ?override_configfile:bool
+val set_default_max_persistent_data_tab_sessions_per_group :
+   ?override_configfile:bool
   -> int option
   -> unit
 (** Sets the maximum number of persistent data tab sessions in a session
     group (see above).
 *)
 
-val set_default_max_volatile_tab_sessions_per_group
-  :  ?override_configfile:bool
+val set_default_max_volatile_tab_sessions_per_group :
+   ?override_configfile:bool
   -> int
   -> unit
 (** Sets the maximum number of volatile tab sessions (data and service)
@@ -413,8 +413,8 @@ val set_ipv4_subnet_mask : ?override_configfile:bool -> int -> unit
 val set_ipv6_subnet_mask : ?override_configfile:bool -> int -> unit
 (** Sets the mask for subnet (IPV6). *)
 
-val set_max_service_states_for_group_or_subnet
-  :  scope:Eliom_common.user_scope
+val set_max_service_states_for_group_or_subnet :
+   scope:Eliom_common.user_scope
   -> ?secure:bool
   -> int
   -> unit
@@ -422,8 +422,8 @@ val set_max_service_states_for_group_or_subnet
     group (or for the client sub network, if there is no group).
 *)
 
-val set_max_volatile_data_states_for_group_or_subnet
-  :  scope:Eliom_common.user_scope
+val set_max_volatile_data_states_for_group_or_subnet :
+   scope:Eliom_common.user_scope
   -> ?secure:bool
   -> int
   -> unit
@@ -431,8 +431,8 @@ val set_max_volatile_data_states_for_group_or_subnet
     group (or for the client sub network, if there is no group).
 *)
 
-val set_max_volatile_states_for_group_or_subnet
-  :  scope:Eliom_common.user_scope
+val set_max_volatile_states_for_group_or_subnet :
+   scope:Eliom_common.user_scope
   -> ?secure:bool
   -> int
   -> unit
@@ -459,8 +459,8 @@ val set_max_volatile_states_for_group_or_subnet
     which simulates some kind of "tab cookies".
 *)
 
-val set_service_cookie_exp_date
-  :  cookie_scope:Eliom_common.cookie_scope
+val set_service_cookie_exp_date :
+   cookie_scope:Eliom_common.cookie_scope
   -> ?secure:bool
   -> float option
   -> unit
@@ -468,8 +468,8 @@ val set_service_cookie_exp_date
     (see above).
 *)
 
-val set_volatile_data_cookie_exp_date
-  :  cookie_scope:Eliom_common.cookie_scope
+val set_volatile_data_cookie_exp_date :
+   cookie_scope:Eliom_common.cookie_scope
   -> ?secure:bool
   -> float option
   -> unit
@@ -477,8 +477,8 @@ val set_volatile_data_cookie_exp_date
     above).
 *)
 
-val set_persistent_data_cookie_exp_date
-  :  cookie_scope:Eliom_common.cookie_scope
+val set_persistent_data_cookie_exp_date :
+   cookie_scope:Eliom_common.cookie_scope
   -> ?secure:bool
   -> float option
   -> unit Lwt.t
@@ -520,8 +520,8 @@ val set_persistent_data_cookie_exp_date
     (for example in the site configuration Web interface).
 *)
 
-val set_global_volatile_state_timeout
-  :  cookie_scope:[< Eliom_common.cookie_scope]
+val set_global_volatile_state_timeout :
+   cookie_scope:[< Eliom_common.cookie_scope]
   -> ?secure:bool
   -> ?recompute_expdates:bool
   -> ?override_configfile:bool
@@ -531,8 +531,8 @@ val set_global_volatile_state_timeout
     service session and volatile data session).
 *)
 
-val set_global_service_state_timeout
-  :  cookie_scope:[< Eliom_common.cookie_scope]
+val set_global_service_state_timeout :
+   cookie_scope:[< Eliom_common.cookie_scope]
   -> ?secure:bool
   -> ?recompute_expdates:bool
   -> ?override_configfile:bool
@@ -540,14 +540,14 @@ val set_global_service_state_timeout
   -> unit
 (** Sets the (server side) timeout for service states. *)
 
-val set_default_global_service_state_timeout
-  :  cookie_level:[< Eliom_common.cookie_level]
+val set_default_global_service_state_timeout :
+   cookie_level:[< Eliom_common.cookie_level]
   -> ?override_configfile:bool
   -> float option
   -> unit
 
-val set_global_volatile_data_state_timeout
-  :  cookie_scope:[< Eliom_common.cookie_scope]
+val set_global_volatile_data_state_timeout :
+   cookie_scope:[< Eliom_common.cookie_scope]
   -> ?secure:bool
   -> ?recompute_expdates:bool
   -> ?override_configfile:bool
@@ -556,14 +556,14 @@ val set_global_volatile_data_state_timeout
 (** Sets the (server side) timeout for volatile (= "in memory") data states.
 *)
 
-val set_default_global_volatile_data_state_timeout
-  :  cookie_level:[< Eliom_common.cookie_level]
+val set_default_global_volatile_data_state_timeout :
+   cookie_level:[< Eliom_common.cookie_level]
   -> ?override_configfile:bool
   -> float option
   -> unit
 
-val set_global_persistent_data_state_timeout
-  :  cookie_scope:[< Eliom_common.cookie_scope]
+val set_global_persistent_data_state_timeout :
+   cookie_scope:[< Eliom_common.cookie_scope]
   -> ?secure:bool
   -> ?recompute_expdates:bool
   -> ?override_configfile:bool
@@ -572,30 +572,30 @@ val set_global_persistent_data_state_timeout
 (** Sets the (server side) timeout for persistent states.
 *)
 
-val set_default_global_persistent_data_state_timeout
-  :  cookie_level:[< Eliom_common.cookie_level]
+val set_default_global_persistent_data_state_timeout :
+   cookie_level:[< Eliom_common.cookie_level]
   -> ?override_configfile:bool
   -> float option
   -> unit
 
-val get_global_service_state_timeout
-  :  ?secure:bool
+val get_global_service_state_timeout :
+   ?secure:bool
   -> cookie_scope:[< Eliom_common.cookie_scope]
   -> unit
   -> float option
 (** Returns the (server side) timeout for service states.
 *)
 
-val get_global_volatile_data_state_timeout
-  :  ?secure:bool
+val get_global_volatile_data_state_timeout :
+   ?secure:bool
   -> cookie_scope:[< Eliom_common.cookie_scope]
   -> unit
   -> float option
 (** Returns the (server side) timeout for "volatile data" states.
 *)
 
-val get_global_persistent_data_state_timeout
-  :  ?secure:bool
+val get_global_persistent_data_state_timeout :
+   ?secure:bool
   -> cookie_scope:[< Eliom_common.cookie_scope]
   -> unit
   -> float option
@@ -604,24 +604,24 @@ val get_global_persistent_data_state_timeout
 
 (** {3 Personalizing timeouts for current state} *)
 
-val set_service_state_timeout
-  :  cookie_scope:Eliom_common.cookie_scope
+val set_service_state_timeout :
+   cookie_scope:Eliom_common.cookie_scope
   -> ?secure:bool
   -> float option
   -> unit
 (** sets the timeout for service state (server side) for current user,
    in seconds. [None] = no timeout *)
 
-val unset_service_state_timeout
-  :  cookie_scope:[< Eliom_common.cookie_scope]
+val unset_service_state_timeout :
+   cookie_scope:[< Eliom_common.cookie_scope]
   -> ?secure:bool
   -> unit
   -> unit
 (** remove the service state timeout for current user
    (and turn back to the default). *)
 
-val get_service_state_timeout
-  :  cookie_scope:[< Eliom_common.cookie_scope]
+val get_service_state_timeout :
+   cookie_scope:[< Eliom_common.cookie_scope]
   -> ?secure:bool
   -> unit
   -> float option
@@ -629,24 +629,24 @@ val get_service_state_timeout
     [None] = no timeout
  *)
 
-val set_volatile_data_state_timeout
-  :  cookie_scope:[< Eliom_common.cookie_scope]
+val set_volatile_data_state_timeout :
+   cookie_scope:[< Eliom_common.cookie_scope]
   -> ?secure:bool
   -> float option
   -> unit
 (** sets the (server side) timeout for volatile data state for current user,
    in seconds. [None] = no timeout *)
 
-val unset_volatile_data_state_timeout
-  :  cookie_scope:[< Eliom_common.cookie_scope]
+val unset_volatile_data_state_timeout :
+   cookie_scope:[< Eliom_common.cookie_scope]
   -> ?secure:bool
   -> unit
   -> unit
 (** remove the "volatile data" state timeout for current user
    (and turn back to the default). *)
 
-val get_volatile_data_state_timeout
-  :  cookie_scope:[< Eliom_common.cookie_scope]
+val get_volatile_data_state_timeout :
+   cookie_scope:[< Eliom_common.cookie_scope]
   -> ?secure:bool
   -> unit
   -> float option
@@ -654,24 +654,24 @@ val get_volatile_data_state_timeout
     [None] = no timeout
  *)
 
-val set_persistent_data_state_timeout
-  :  cookie_scope:[< Eliom_common.cookie_scope]
+val set_persistent_data_state_timeout :
+   cookie_scope:[< Eliom_common.cookie_scope]
   -> ?secure:bool
   -> float option
   -> unit Lwt.t
 (** sets the (server side) timeout for persistent state for current user,
    in seconds. [None] = no timeout *)
 
-val unset_persistent_data_state_timeout
-  :  cookie_scope:[< Eliom_common.cookie_scope]
+val unset_persistent_data_state_timeout :
+   cookie_scope:[< Eliom_common.cookie_scope]
   -> ?secure:bool
   -> unit
   -> unit Lwt.t
 (** remove the persistent state timeout for current user
    (and turn back to the default). *)
 
-val get_persistent_data_state_timeout
-  :  cookie_scope:[< Eliom_common.cookie_scope]
+val get_persistent_data_state_timeout :
+   cookie_scope:[< Eliom_common.cookie_scope]
   -> ?secure:bool
   -> unit
   -> float option Lwt.t
@@ -703,8 +703,8 @@ val discard_everything : unit -> unit Lwt.t
 
 (*CCC missing ~secure? *)
 
-val discard_all
-  :  scope:Eliom_common.user_scope
+val discard_all :
+   scope:Eliom_common.user_scope
   -> ?secure:bool
   -> unit
   -> unit Lwt.t
@@ -712,8 +712,8 @@ val discard_all
 
 (*VVV missing: scope group *)
 
-val discard_all_data
-  :  ?persistent:bool
+val discard_all_data :
+   ?persistent:bool
   -> scope:Eliom_common.user_scope
   -> ?secure:bool
   -> unit
@@ -727,8 +727,8 @@ val discard_all_data
 (*VVV missing: scope group *)
 (*VVV missing ~secure? *)
 
-val discard_all_services
-  :  scope:Eliom_common.user_scope
+val discard_all_services :
+   scope:Eliom_common.user_scope
   -> ?secure:bool
   -> unit
   -> unit Lwt.t
@@ -760,27 +760,27 @@ module Ext : sig
       and the second one to the kind of state (volatile or persistent data,
       or service state) *)
 
-  val volatile_data_group_state
-    :  ?scope:Eliom_common.session_group_scope
+  val volatile_data_group_state :
+     ?scope:Eliom_common.session_group_scope
     -> string
     -> ([> `Session_group], [> `Data]) state
   (** [volatile_data_group_state ~scope n] returns the state corresponding to
       the group named [n] in scope [scope]. *)
 
-  val persistent_data_group_state
-    :  ?scope:Eliom_common.session_group_scope
+  val persistent_data_group_state :
+     ?scope:Eliom_common.session_group_scope
     -> string
     -> ([> `Session_group], [> `Pers]) state
   (** Same for persistent data *)
 
-  val service_group_state
-    :  ?scope:Eliom_common.session_group_scope
+  val service_group_state :
+     ?scope:Eliom_common.session_group_scope
     -> string
     -> ([> `Session_group], [> `Service]) state
   (** Same for services *)
 
-  val current_volatile_data_state
-    :  ?secure:bool
+  val current_volatile_data_state :
+     ?secure:bool
     -> ?scope:Eliom_common.user_scope
     -> unit
     -> ([< Eliom_common.user_level], [< `Data]) state
@@ -791,22 +791,22 @@ module Ext : sig
       expired.
   *)
 
-  val current_persistent_data_state
-    :  ?secure:bool
+  val current_persistent_data_state :
+     ?secure:bool
     -> ?scope:Eliom_common.user_scope
     -> unit
     -> ([< Eliom_common.user_level], [< `Pers]) state Lwt.t
   (** Same for persistent data *)
 
-  val current_service_state
-    :  ?secure:bool
+  val current_service_state :
+     ?secure:bool
     -> ?scope:Eliom_common.user_scope
     -> unit
     -> ([< Eliom_common.user_level], [< `Service]) state
   (** Same for services *)
 
-  val discard_state
-    :  ?sitedata:Eliom_common.sitedata
+  val discard_state :
+     ?sitedata:Eliom_common.sitedata
     -> state:('a, 'b) state
     -> unit
     -> unit Lwt.t
@@ -815,8 +815,8 @@ module Ext : sig
       parameter.
   *)
 
-  val fold_volatile_sub_states
-    :  ?sitedata:Eliom_common.sitedata
+  val fold_volatile_sub_states :
+     ?sitedata:Eliom_common.sitedata
     -> state:([< `Session_group | `Session], ([< `Data | `Service] as 'k)) state
     -> ('a -> ([< `Session | `Client_process], 'k) state -> 'a)
     -> 'a
@@ -829,8 +829,8 @@ module Ext : sig
       during the initialisation phase of the Eliom module.
   *)
 
-  val iter_volatile_sub_states
-    :  ?sitedata:Eliom_common.sitedata
+  val iter_volatile_sub_states :
+     ?sitedata:Eliom_common.sitedata
     -> state:([< `Session_group | `Session], ([< `Data | `Service] as 'k)) state
     -> (([< `Session | `Client_process], 'k) state -> unit)
     -> unit
@@ -839,12 +839,12 @@ module Ext : sig
       parameter.
   *)
 
-  val fold_sub_states
-    :  ?sitedata:Eliom_common.sitedata
+  val fold_sub_states :
+     ?sitedata:Eliom_common.sitedata
     -> state:
          ( [< `Session_group | `Session]
-         , ([< `Data | `Pers | `Service] as 'k) )
-         state
+           , ([< `Data | `Pers | `Service] as 'k) )
+           state
     -> ('a -> ([< `Session | `Client_process], 'k) state -> 'a Lwt.t)
     -> 'a
     -> 'a Lwt.t
@@ -854,8 +854,8 @@ module Ext : sig
       parameter.
   *)
 
-  val iter_sub_states
-    :  ?sitedata:Eliom_common.sitedata
+  val iter_sub_states :
+     ?sitedata:Eliom_common.sitedata
     -> state:([< `Session_group | `Session], 'k) state
     -> (([< `Session | `Client_process], 'k) state -> unit Lwt.t)
     -> unit Lwt.t
@@ -869,46 +869,46 @@ module Ext : sig
     (** Functions to access table data.
         Prefer using Eliom references. *)
 
-    val get_volatile_data
-      :  state:([< `Session_group | `Session | `Client_process], [< `Data]) state
+    val get_volatile_data :
+       state:([< `Session_group | `Session | `Client_process], [< `Data]) state
       -> table:'a volatile_table
       -> 'a
     (** Raises [Not_found] if no data in the table for the cookie. *)
 
-    val get_persistent_data
-      :  state:([< `Session_group | `Session | `Client_process], [< `Pers]) state
+    val get_persistent_data :
+       state:([< `Session_group | `Session | `Client_process], [< `Pers]) state
       -> table:'a persistent_table
       -> 'a Lwt.t
     (** Fails with lwt exception [Not_found]
         if no data in the table for the cookie. *)
 
-    val set_volatile_data
-      :  state:([< `Session_group | `Session | `Client_process], [< `Data]) state
+    val set_volatile_data :
+       state:([< `Session_group | `Session | `Client_process], [< `Data]) state
       -> table:'a volatile_table
       -> 'a
       -> unit
 
-    val set_persistent_data
-      :  state:([< `Session_group | `Session | `Client_process], [< `Pers]) state
+    val set_persistent_data :
+       state:([< `Session_group | `Session | `Client_process], [< `Pers]) state
       -> table:'a persistent_table
       -> 'a
       -> unit Lwt.t
     (** Fails with lwt exception [Not_found]
         if no data in the table for the cookie. *)
 
-    val remove_volatile_data
-      :  state:([< `Session_group | `Session | `Client_process], [< `Data]) state
+    val remove_volatile_data :
+       state:([< `Session_group | `Session | `Client_process], [< `Data]) state
       -> table:'a volatile_table
       -> unit
 
-    val remove_persistent_data
-      :  state:([< `Session_group | `Session | `Client_process], [< `Pers]) state
+    val remove_persistent_data :
+       state:([< `Session_group | `Session | `Client_process], [< `Pers]) state
       -> table:'a persistent_table
       -> unit Lwt.t
   end
 
-  val get_service_cookie_info
-    :  ?sitedata:Eliom_common.sitedata
+  val get_service_cookie_info :
+     ?sitedata:Eliom_common.sitedata
     -> ([< Eliom_common.cookie_level], [`Service]) state
     -> service_cookie_info
   (** Get the infomration about cookies (timeouts, etc.).
@@ -916,57 +916,57 @@ module Ext : sig
       parameter.
   *)
 
-  val get_volatile_data_cookie_info
-    :  ?sitedata:Eliom_common.sitedata
+  val get_volatile_data_cookie_info :
+     ?sitedata:Eliom_common.sitedata
     -> ([< Eliom_common.cookie_level], [`Data]) state
     -> data_cookie_info
   (** See {!fold_volatile_sub_states} for explanation about the [?sitedata]
       parameter.
   *)
 
-  val get_persistent_cookie_info
-    :  ([< Eliom_common.cookie_level], [`Pers]) state
+  val get_persistent_cookie_info :
+     ([< Eliom_common.cookie_level], [`Pers]) state
     -> persistent_cookie_info Lwt.t
 
-  val get_service_cookie_scope
-    :  cookie:service_cookie_info
+  val get_service_cookie_scope :
+     cookie:service_cookie_info
     -> Eliom_common.user_scope
 
-  val get_volatile_data_cookie_scope
-    :  cookie:data_cookie_info
+  val get_volatile_data_cookie_scope :
+     cookie:data_cookie_info
     -> Eliom_common.user_scope
 
-  val get_persistent_data_cookie_scope
-    :  cookie:persistent_cookie_info
+  val get_persistent_data_cookie_scope :
+     cookie:persistent_cookie_info
     -> Eliom_common.user_scope
 
-  val set_service_cookie_timeout
-    :  cookie:service_cookie_info
+  val set_service_cookie_timeout :
+     cookie:service_cookie_info
     -> float option
     -> unit
 
-  val set_volatile_data_cookie_timeout
-    :  cookie:data_cookie_info
+  val set_volatile_data_cookie_timeout :
+     cookie:data_cookie_info
     -> float option
     -> unit
 
-  val set_persistent_data_cookie_timeout
-    :  cookie:persistent_cookie_info
+  val set_persistent_data_cookie_timeout :
+     cookie:persistent_cookie_info
     -> float option
     -> unit Lwt.t
 
   val get_service_cookie_timeout : cookie:service_cookie_info -> timeout
   val get_volatile_data_cookie_timeout : cookie:data_cookie_info -> timeout
 
-  val get_persistent_data_cookie_timeout
-    :  cookie:persistent_cookie_info
+  val get_persistent_data_cookie_timeout :
+     cookie:persistent_cookie_info
     -> timeout
 
   val unset_service_cookie_timeout : cookie:service_cookie_info -> unit
   val unset_volatile_data_cookie_timeout : cookie:data_cookie_info -> unit
 
-  val unset_persistent_data_cookie_timeout
-    :  cookie:persistent_cookie_info
+  val unset_persistent_data_cookie_timeout :
+     cookie:persistent_cookie_info
     -> unit Lwt.t
 
   val get_session_group_list : unit -> string list
@@ -978,37 +978,37 @@ module Ext : sig
       [Lwt.pause] is called automatically after each iteration.
    *)
 
-  val iter_volatile_data_cookies
-    :  (data_cookie_info -> unit Lwt.t)
+  val iter_volatile_data_cookies :
+     (data_cookie_info -> unit Lwt.t)
     -> unit Lwt.t
   (** Iterator on data cookies. [Lwt.pause] is called automatically
       after each iteration.
    *)
 
-  val iter_persistent_data_cookies
-    :  (persistent_cookie_info -> unit Lwt.t)
+  val iter_persistent_data_cookies :
+     (persistent_cookie_info -> unit Lwt.t)
     -> unit Lwt.t
   (** Iterator on persistent cookies. [Lwt.pause] is called automatically
       after each iteration. *)
 
-  val fold_service_cookies
-    :  (service_cookie_info -> 'b -> 'b Lwt.t)
+  val fold_service_cookies :
+     (service_cookie_info -> 'b -> 'b Lwt.t)
     -> 'b
     -> 'b Lwt.t
   (** Iterator on service cookies. [Lwt.pause] is called automatically
       after each iteration.
   *)
 
-  val fold_volatile_data_cookies
-    :  (data_cookie_info -> 'b -> 'b Lwt.t)
+  val fold_volatile_data_cookies :
+     (data_cookie_info -> 'b -> 'b Lwt.t)
     -> 'b
     -> 'b Lwt.t
   (** Iterator on data cookies. [Lwt.pause] is called automatically
      after each iteration.
    *)
 
-  val fold_persistent_data_cookies
-    :  (persistent_cookie_info -> 'b -> 'b Lwt.t)
+  val fold_persistent_data_cookies :
+     (persistent_cookie_info -> 'b -> 'b Lwt.t)
     -> 'b
     -> 'b Lwt.t
   (** Iterator on persistent cookies. [Lwt.pause] is called automatically
@@ -1031,8 +1031,8 @@ type 'a state_data = No_data | Data_session_expired | Data of 'a
 
 (** {4 In memory state data} *)
 
-val create_volatile_table
-  :  scope:Eliom_common.user_scope
+val create_volatile_table :
+   scope:Eliom_common.user_scope
   -> ?secure:bool
   -> unit
   -> 'a volatile_table
@@ -1069,16 +1069,16 @@ val remove_volatile_data : table:'a volatile_table -> unit -> unit
 
 (** {4 Persistent state data} *)
 
-val create_persistent_table
-  :  scope:Eliom_common.user_scope
+val create_persistent_table :
+   scope:Eliom_common.user_scope
   -> ?secure:bool
   -> string
   -> 'a persistent_table Lwt.t
 (** creates a table on hard disk where you can store the session data
     for all users. It uses {!Ocsipersist}.  (low level) *)
 
-val get_persistent_data
-  :  table:'a persistent_table
+val get_persistent_data :
+   table:'a persistent_table
   -> unit
   -> 'a state_data Lwt.t
 (** gets persistent session data for the current persistent session (if any).
@@ -1098,7 +1098,7 @@ val remove_persistent_data : table:'a persistent_table -> unit -> unit Lwt.t
 (**/**)
 
 (*
-(** {3 Default timeouts} *)
+   (** {3 Default timeouts} *)
 
 (** returns the default timeout for service sessions (server side).
     The default timeout is common for all sessions for which no other value
@@ -1166,8 +1166,8 @@ val set_default_persistent_data_session_timeout : float option -> unit
 (** {3 Other low level functions}
     You probably don't need these functions. *)
 
-val get_persistent_data_cookie
-  :  cookie_scope:Eliom_common.cookie_scope
+val get_persistent_data_cookie :
+   cookie_scope:Eliom_common.cookie_scope
   -> ?secure:bool
   -> unit
   -> Eliom_common.Hashed_cookies.t option Lwt.t
@@ -1175,8 +1175,8 @@ val get_persistent_data_cookie
     Returns [None] is no session is active.
  *)
 
-val get_service_cookie
-  :  cookie_scope:Eliom_common.cookie_scope
+val get_service_cookie :
+   cookie_scope:Eliom_common.cookie_scope
   -> ?secure:bool
   -> unit
   -> Eliom_common.Hashed_cookies.t option
@@ -1184,8 +1184,8 @@ val get_service_cookie
     Returns [None] is no session is active.
  *)
 
-val get_volatile_data_cookie
-  :  cookie_scope:Eliom_common.cookie_scope
+val get_volatile_data_cookie :
+   cookie_scope:Eliom_common.cookie_scope
   -> ?secure:bool
   -> unit
   -> Eliom_common.Hashed_cookies.t option
@@ -1210,22 +1210,22 @@ val number_of_persistent_table_elements : unit -> (string * int) list Lwt.t
 
 val get_global_table : unit -> Eliom_common.tables
 
-val get_session_service_table
-  :  sp:Eliom_common.server_params
+val get_session_service_table :
+   sp:Eliom_common.server_params
   -> scope:Eliom_common.user_scope
   -> ?secure:bool
   -> unit
   -> Eliom_common.tables ref
 
-val get_session_service_table_if_exists
-  :  sp:Eliom_common.server_params
+val get_session_service_table_if_exists :
+   sp:Eliom_common.server_params
   -> scope:Eliom_common.user_scope
   -> ?secure:bool
   -> unit
   -> Eliom_common.tables ref
 
-val create_volatile_table_during_session_
-  :  scope:Eliom_common.user_scope
+val create_volatile_table_during_session_ :
+   scope:Eliom_common.user_scope
   -> secure:bool
   -> Eliom_common.sitedata
   -> 'a volatile_table
