@@ -21,8 +21,8 @@
 val cookieset_to_json : Ocsigen_cookie_map.t -> string
 val make_new_session_id : unit -> string
 
-val get_cookie_info
-  :  float
+val get_cookie_info :
+   float
   -> Eliom_common.sitedata
   -> Eliom_common.SessionCookies.key Eliom_common.Full_state_name_table.t
   -> Eliom_common.SessionCookies.key Eliom_common.Full_state_name_table.t
@@ -33,26 +33,26 @@ val get_cookie_info
   -> Eliom_common.tables Eliom_common.cookie_info
      * Eliom_common.Full_state_name_table.key list
 
-val new_service_cookie_table
-  :  unit
+val new_service_cookie_table :
+   unit
   -> Eliom_common.tables Eliom_common.Service_cookie.table
 
 val new_data_cookie_table : unit -> Eliom_common.Data_cookie.table
 
-val compute_session_cookies_to_send
-  :  Eliom_common.sitedata
+val compute_session_cookies_to_send :
+   Eliom_common.sitedata
   -> Eliom_common.tables Eliom_common.cookie_info
   -> Ocsigen_cookie_map.t
   -> Ocsigen_cookie_map.t Lwt.t
 
-val compute_cookies_to_send
-  :  Eliom_common.sitedata
+val compute_cookies_to_send :
+   Eliom_common.sitedata
   -> Eliom_common.tables Eliom_common.cookie_info
   -> Ocsigen_cookie_map.t
   -> Ocsigen_cookie_map.t Lwt.t
 
-val compute_new_ri_cookies
-  :  float
+val compute_new_ri_cookies :
+   float
   -> string list
   -> string Ocsigen_cookie_map.Map_inner.t
   -> Eliom_common.tables Eliom_common.cookie_info
@@ -81,8 +81,8 @@ module Persistent_cookies : sig
   val add : string -> cookie -> unit Lwt.t
   val replace_if_exists : string -> cookie -> unit Lwt.t
 
-  val garbage_collect
-    :  section:Lwt_log_core.Section.t
+  val garbage_collect :
+     section:Lwt_log_core.Section.t
     -> (Cookies.key -> unit Lwt.t)
     -> unit Lwt.t
 end
