@@ -19,8 +19,8 @@
  *)
 val def_handler : exn -> 'b Lwt.t
 
-val execute
-  :  float
+val execute :
+   float
   -> (float
       -> Eliom_common.info
       -> Eliom_common.sitedata
@@ -29,14 +29,14 @@ val execute
   -> Eliom_common.sitedata
   -> Ocsigen_response.t Lwt.t
 
-val gen
-  :  Eliom_extension.eliom_extension_sig option
+val gen :
+   Eliom_extension.eliom_extension_sig option
   -> Eliom_common.sitedata
   -> Ocsigen_extensions.request_state
   -> Ocsigen_extensions.answer Lwt.t
 
-val update_cookie_table
-  :  ?now:float
+val update_cookie_table :
+   ?now:float
   -> Eliom_common.sitedata
   -> Eliom_common.tables Eliom_common.cookie_info
   -> unit Lwt.t
