@@ -6,8 +6,8 @@ module type ELIOM = sig
 end
 
 module Make (_ : ELIOM) : sig
-  val dispatcher
-    :  ?oasis_executables:Ocamlbuild_plugin.Pathname.t list
+  val dispatcher :
+     ?oasis_executables:Ocamlbuild_plugin.Pathname.t list
     -> Ocamlbuild_plugin.hook
     -> unit
   (** The main dispatcher
@@ -48,8 +48,8 @@ module type INTERNALS = sig
 end
 
 module MakeIntern (_ : INTERNALS) (_ : ELIOM) : sig
-  val dispatcher
-    :  ?oasis_executables:Ocamlbuild_plugin.Pathname.t list
+  val dispatcher :
+     ?oasis_executables:Ocamlbuild_plugin.Pathname.t list
     -> Ocamlbuild_plugin.hook
     -> unit
 end
